work/$(DISTFILE): work cvs
	@(mkdir -p work)
	if test ! -f work/$(DISTFILE); then \
	  cd work && wget --passive $(DISTLOCATION)/$(DISTFILE); \
	fi

## check if the root can build rpms
rpm-build:
	@if test ! -f $(BITCHESROOT)/state/rpm-build; then \
	  echo "Prepare the build root first !"; exit 1; \
	fi

## build the rpm
rpm: work/$(DISTFILE) rpm-buildrequires result-clear
	make lock
	mkdir -p $(RESULTDIR)
	$(CHROOT) $(ROOT) apt-get -y install $(REQUIRES)
	cp work/$(DISTFILE) $(ROOT)
	$(CHROOT) $(ROOT) chown root:root $(DISTFILE)
	$(CHROOT) $(ROOT) mv $(DISTFILE) /usr/src/redhat/SOURCES
	if test "x$(SPEC)" = "x"; then \
	  $(CHROOT) $(ROOT) rpm -tb /usr/src/redhat/SOURCES/$(DISTFILE) > $(RESULTDIR)/rpm.log 2>&1 || exit 1; \
	else \
	  cp $(SPEC) $(ROOT); \
	  $(CHROOT) $(ROOT) chown root:root $(SPEC); \
	  $(CHROOT) $(ROOT) mv $(SPEC) /usr/src/redhat/SPECS; \
	  $(CHROOT) $(ROOT) rpm -ba /usr/src/redhat/SPECS/$(SPEC) > $(RESULTDIR)/rpm.log 2>&1 || exit 1; \
	fi
	@grep "Wrote: " $(RESULTDIR)/rpm.log | cut -d\  -f2 | \
	  xargs $(CHROOT) $(ROOT) mv --target-directory=/
	mv $(ROOT)/*.rpm $(RESULTDIR)
	make unlock
	@echo "Build of $(DIST) succeeded."

## get the spec out of the dist
work/$(PACKAGE).spec: work/$(DISTFILE)
	@if test "x$(SPEC)" = "x"; then \
          cd work; \
          tar xzf $(DISTFILE) $(DIST)/$(PACKAGE).spec; \
	  mv $(DIST)/$(PACKAGE).spec .; \
	else \
          cp $(SPEC) work/$(PACKAGE).spec; \
	fi

## install all of the necessary build requires
## filter out any word not starting with a letter from the buildrequires
## this line of perl works for one line but not on a pipe
## perl -ne 'print join (" ", grep {/^[a-zA-Z]\w*$/} split (/ /));'
rpm-buildrequires: rpm-build work/$(PACKAGE).spec
	make lock
	grep "BuildRequires:" work/$(PACKAGE).spec | \
          sed 's@BuildRequires:@@' | \
	  sed -e"s/^/ /" -e "s/[[:space:]][^a-zA-Z[:space:]][^[:space:]]*//g" | \
	  xargs $(CHROOT) $(ROOT) apt-get -y install
	make unlock

## check out stuff from cvs if CVSROOT is defined
cvs:
	@if test "x$(CVSROOT)" != "x" && test ! -f work/$(DISTFILE); then \
	  make cvs-dist; fi

cvs-dist:
	cd work && cvs -d$(CVSROOT) co $(CVSMODULE) || exit 1; \
        cd $(CVSMODULE); \
        $(AUTOGEN); $(CONFIGURE); $(MAKEDIST); \
        mv *.tar.gz ..;

work:
	mkdir -p work

### clear the result dir for this package
result-clear:
	if test "x$(RESULTDIR)" != "x"; then \
	  mkdir -p $(RESULTDIR); rm -rf $(RESULTDIR)/*; \
        fi

### clear the work dir
work-clear:
	rm -rf work

clear:  work-clear result-clear
